# -*- coding: utf-8 -*-
info = {
    "name": "kln",
    "date_order": "DMY",
    "january": [
        "mulgul",
        "mul"
    ],
    "february": [
        "ng'atyaato",
        "ngat"
    ],
    "march": [
        "kiptaamo",
        "taa"
    ],
    "april": [
        "iwootkuut",
        "iwo"
    ],
    "may": [
        "mamuut",
        "mam"
    ],
    "june": [
        "paagi",
        "paa"
    ],
    "july": [
        "ng'eiyeet",
        "nge"
    ],
    "august": [
        "rooptui",
        "roo"
    ],
    "september": [
        "bureet",
        "bur"
    ],
    "october": [
        "epeeso",
        "epe"
    ],
    "november": [
        "kipsuunde ne taai",
        "kpt"
    ],
    "december": [
        "kipsuunde nebo aeng'",
        "kpa"
    ],
    "monday": [
        "kotaai",
        "kot"
    ],
    "tuesday": [
        "koaeng'",
        "koo"
    ],
    "wednesday": [
        "kosomok",
        "kos"
    ],
    "thursday": [
        "koang'wan",
        "koa"
    ],
    "friday": [
        "komuut",
        "kom"
    ],
    "saturday": [
        "kolo",
        "kol"
    ],
    "sunday": [
        "kotisap",
        "kts"
    ],
    "am": [
        "krn",
        "karoon"
    ],
    "pm": [
        "koosk",
        "kooskoliny"
    ],
    "year": [
        "kenyit"
    ],
    "month": [
        "arawet"
    ],
    "week": [
        "wikit"
    ],
    "day": [
        "betut"
    ],
    "hour": [
        "sait"
    ],
    "minute": [
        "minitit"
    ],
    "second": [
        "sekondit"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "amut"
        ],
        "0 day ago": [
            "raini"
        ],
        "in 1 day": [
            "mutai"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "zgh",
    "date_order": "DMY",
    "january": [
        "ⵉⵏⵏⴰⵢⵔ",
        "ⵉⵏⵏ"
    ],
    "february": [
        "ⴱⵕⴰⵢⵕ",
        "ⴱⵕⴰ"
    ],
    "march": [
        "ⵎⴰⵕⵚ",
        "ⵎⴰⵕ"
    ],
    "april": [
        "ⵉⴱⵔⵉⵔ",
        "ⵉⴱⵔ"
    ],
    "may": [
        "ⵎⴰⵢⵢⵓ",
        "ⵎⴰⵢ"
    ],
    "june": [
        "ⵢⵓⵏⵢⵓ",
        "ⵢⵓⵏ"
    ],
    "july": [
        "ⵢⵓⵍⵢⵓⵣ",
        "ⵢⵓⵍ"
    ],
    "august": [
        "ⵖⵓⵛⵜ",
        "ⵖⵓⵛ"
    ],
    "september": [
        "ⵛⵓⵜⴰⵏⴱⵉⵔ",
        "ⵛⵓⵜ"
    ],
    "october": [
        "ⴽⵜⵓⴱⵔ",
        "ⴽⵜⵓ"
    ],
    "november": [
        "ⵏⵓⵡⴰⵏⴱⵉⵔ",
        "ⵏⵓⵡ"
    ],
    "december": [
        "ⴷⵓⵊⴰⵏⴱⵉⵔ",
        "ⴷⵓⵊ"
    ],
    "monday": [
        "ⴰⵢⵏⴰⵙ",
        "ⴰⵢⵏ"
    ],
    "tuesday": [
        "ⴰⵙⵉⵏⴰⵙ",
        "ⴰⵙⵉ"
    ],
    "wednesday": [
        "ⴰⴽⵕⴰⵙ",
        "ⴰⴽⵕ"
    ],
    "thursday": [
        "ⴰⴽⵡⴰⵙ",
        "ⴰⴽⵡ"
    ],
    "friday": [
        "ⴰⵙⵉⵎⵡⴰⵙ",
        "ⴰⵙⵉⵎ"
    ],
    "saturday": [
        "ⴰⵙⵉⴹⵢⴰⵙ",
        "ⴰⵙⵉⴹ"
    ],
    "sunday": [
        "ⴰⵙⴰⵎⴰⵙ",
        "ⴰⵙⴰ"
    ],
    "am": [
        "ⵜⵉⴼⴰⵡⵜ"
    ],
    "pm": [
        "ⵜⴰⴷⴳⴳⵯⴰⵜ"
    ],
    "year": [
        "ⴰⵙⴳⴳⵯⴰⵙ"
    ],
    "month": [
        "ⴰⵢⵢⵓⵔ"
    ],
    "week": [
        "ⵉⵎⴰⵍⴰⵙⵙ"
    ],
    "day": [
        "ⴰⵙⵙ"
    ],
    "hour": [
        "ⵜⴰⵙⵔⴰⴳⵜ"
    ],
    "minute": [
        "ⵜⵓⵙⴷⵉⴷⵜ"
    ],
    "second": [
        "ⵜⴰⵙⵉⵏⵜ"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "ⵉⴹⵍⵍⵉ"
        ],
        "0 day ago": [
            "ⴰⵙⵙⴰ"
        ],
        "in 1 day": [
            "ⴰⵙⴽⴽⴰ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "ha",
    "date_order": "DMY",
    "january": [
        "janairu",
        "jan"
    ],
    "february": [
        "faburairu",
        "fab"
    ],
    "march": [
        "maris",
        "mar"
    ],
    "april": [
        "afirilu",
        "afi"
    ],
    "may": [
        "mayu",
        "may"
    ],
    "june": [
        "yuni",
        "yun"
    ],
    "july": [
        "yuli",
        "yul"
    ],
    "august": [
        "agusta",
        "agu"
    ],
    "september": [
        "satumba",
        "sat"
    ],
    "october": [
        "oktoba",
        "okt"
    ],
    "november": [
        "nuwamba",
        "nuw"
    ],
    "december": [
        "disamba",
        "dis"
    ],
    "monday": [
        "litinin",
        "lit"
    ],
    "tuesday": [
        "talata",
        "tal"
    ],
    "wednesday": [
        "laraba",
        "lar"
    ],
    "thursday": [
        "alhamis",
        "alh"
    ],
    "friday": [
        "jumma'a",
        "jum"
    ],
    "saturday": [
        "asabar",
        "asa"
    ],
    "sunday": [
        "lahadi",
        "lah"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "shekara"
    ],
    "month": [
        "wata"
    ],
    "week": [
        "mako"
    ],
    "day": [
        "kwana"
    ],
    "hour": [
        "awa"
    ],
    "minute": [
        "minti"
    ],
    "second": [
        "daƙiƙa"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "jiya"
        ],
        "0 day ago": [
            "yau"
        ],
        "in 1 day": [
            "gobe"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {
        "ha-GH": {
            "name": "ha-GH"
        },
        "ha-NE": {
            "name": "ha-NE"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "ru",
    "date_order": "DMY",
    "january": [
        "январь",
        "янв",
        "января"
    ],
    "february": [
        "февраль",
        "февр",
        "февраля",
        "Фев"
    ],
    "march": [
        "март",
        "марта",
        "мар"
    ],
    "april": [
        "апрель",
        "апр",
        "апреля"
    ],
    "may": [
        "май",
        "мая"
    ],
    "june": [
        "июнь",
        "июня",
        "июн"
    ],
    "july": [
        "июль",
        "июля",
        "июл"
    ],
    "august": [
        "август",
        "авг",
        "августа"
    ],
    "september": [
        "сентябрь",
        "сент",
        "сентября",
        "Сен"
    ],
    "october": [
        "октябрь",
        "окт",
        "октября"
    ],
    "november": [
        "ноябрь",
        "нояб",
        "ноября",
        "Ноя"
    ],
    "december": [
        "декабрь",
        "дек",
        "декабря"
    ],
    "monday": [
        "понедельник",
        "пн"
    ],
    "tuesday": [
        "вторник",
        "вт"
    ],
    "wednesday": [
        "среда",
        "ср",
        "Среду"
    ],
    "thursday": [
        "четверг",
        "чт"
    ],
    "friday": [
        "пятница",
        "пт",
        "Пятницу"
    ],
    "saturday": [
        "суббота",
        "сб",
        "Субботу"
    ],
    "sunday": [
        "воскресенье",
        "вс",
        "Воскресение"
    ],
    "am": [
        "дп"
    ],
    "pm": [
        "пп"
    ],
    "year": [
        "год",
        "г",
        "года",
        "лет"
    ],
    "month": [
        "месяц",
        "мес",
        "месяца",
        "месяцев"
    ],
    "week": [
        "неделя",
        "нед",
        "недели",
        "недель",
        "неделю"
    ],
    "day": [
        "день",
        "дн",
        "дня",
        "дней"
    ],
    "hour": [
        "час",
        "ч",
        "часа",
        "часов"
    ],
    "minute": [
        "минута",
        "мин",
        "минуты",
        "минут",
        "минуту"
    ],
    "second": [
        "секунда",
        "сек",
        "с",
        "секунды",
        "секунд",
        "секунду"
    ],
    "relative-type": {
        "1 year ago": [
            "в прошлом году"
        ],
        "0 year ago": [
            "в этом году"
        ],
        "in 1 year": [
            "в следующем году"
        ],
        "1 month ago": [
            "в прошлом месяце"
        ],
        "0 month ago": [
            "в этом месяце"
        ],
        "in 1 month": [
            "в следующем месяце"
        ],
        "1 week ago": [
            "на прошлой неделе"
        ],
        "0 week ago": [
            "на этой неделе"
        ],
        "in 1 week": [
            "на следующей неделе"
        ],
        "1 day ago": [
            "вчера"
        ],
        "0 day ago": [
            "сегодня"
        ],
        "in 1 day": [
            "завтра"
        ],
        "0 hour ago": [
            "в этом часе"
        ],
        "0 minute ago": [
            "в эту минуту"
        ],
        "0 second ago": [
            "сейчас"
        ],
        "2 day ago": [
            "позавчера"
        ],
        "in 2 day": [
            "послезавтра"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "через (\\d+) год",
            "через (\\d+) года",
            "через (\\d+) г"
        ],
        "\\1 year ago": [
            "(\\d+) год назад",
            "(\\d+) года назад",
            "(\\d+) г назад"
        ],
        "in \\1 month": [
            "через (\\d+) месяц",
            "через (\\d+) месяца",
            "через (\\d+) мес"
        ],
        "\\1 month ago": [
            "(\\d+) месяц назад",
            "(\\d+) месяца назад",
            "(\\d+) мес назад"
        ],
        "in \\1 week": [
            "через (\\d+) неделю",
            "через (\\d+) недели",
            "через (\\d+) нед"
        ],
        "\\1 week ago": [
            "(\\d+) неделю назад",
            "(\\d+) недели назад",
            "(\\d+) нед назад"
        ],
        "in \\1 day": [
            "через (\\d+) день",
            "через (\\d+) дня",
            "через (\\d+) д",
            "через (\\d+) дн"
        ],
        "\\1 day ago": [
            "(\\d+) день назад",
            "(\\d+) дня назад",
            "(\\d+) д назад",
            "(\\d+) дн назад"
        ],
        "in \\1 hour": [
            "через (\\d+) час",
            "через (\\d+) часа",
            "через (\\d+) ч"
        ],
        "\\1 hour ago": [
            "(\\d+) час назад",
            "(\\d+) часа назад",
            "(\\d+) ч назад"
        ],
        "in \\1 minute": [
            "через (\\d+) минуту",
            "через (\\d+) минуты",
            "через (\\d+) мин"
        ],
        "\\1 minute ago": [
            "(\\d+) минуту назад",
            "(\\d+) минуты назад",
            "(\\d+) мин назад"
        ],
        "in \\1 second": [
            "через (\\d+) секунду",
            "через (\\d+) секунды",
            "через (\\d+) сек"
        ],
        "\\1 second ago": [
            "(\\d+) секунду назад",
            "(\\d+) секунды назад",
            "(\\d+) сек назад"
        ]
    },
    "locale_specific": {
        "ru-KZ": {
            "name": "ru-KZ"
        },
        "ru-UA": {
            "name": "ru-UA",
            "am": [
                "am"
            ],
            "pm": [
                "pm"
            ]
        },
        "ru-MD": {
            "name": "ru-MD"
        },
        "ru-KG": {
            "name": "ru-KG"
        },
        "ru-BY": {
            "name": "ru-BY"
        }
    },
    "skip": [
        "около",
        "в",
        "и",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "назад"
    ],
    "in": [
        "в течение",
        "спустя"
    ],
    "simplifications": [
        {
            "^час": "1 час"
        },
        {
            "^минуту": "1 минуту"
        },
        {
            "^секунду": "1 секунду"
        },
        {
            "несколько секунд": "44 секунды"
        }
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "lv",
    "date_order": "DMY",
    "january": [
        "janvāris",
        "janv"
    ],
    "february": [
        "februāris",
        "febr"
    ],
    "march": [
        "marts"
    ],
    "april": [
        "aprīlis",
        "apr"
    ],
    "may": [
        "maijs"
    ],
    "june": [
        "jūnijs",
        "jūn"
    ],
    "july": [
        "jūlijs",
        "jūl"
    ],
    "august": [
        "augusts",
        "aug"
    ],
    "september": [
        "septembris",
        "sept"
    ],
    "october": [
        "oktobris",
        "okt"
    ],
    "november": [
        "novembris",
        "nov"
    ],
    "december": [
        "decembris",
        "dec"
    ],
    "monday": [
        "pirmdiena",
        "pirmd"
    ],
    "tuesday": [
        "otrdiena",
        "otrd"
    ],
    "wednesday": [
        "trešdiena",
        "trešd"
    ],
    "thursday": [
        "ceturtdiena",
        "ceturtd"
    ],
    "friday": [
        "piektdiena",
        "piektd"
    ],
    "saturday": [
        "sestdiena",
        "sestd"
    ],
    "sunday": [
        "svētdiena",
        "svētd"
    ],
    "am": [
        "priekšpusdiena",
        "priekšp",
        "priekšpusdienā"
    ],
    "pm": [
        "pēcpusdiena",
        "pēcpusd",
        "pēcpusdienā",
        "pēcp"
    ],
    "year": [
        "gads",
        "g"
    ],
    "month": [
        "mēnesis",
        "mēn"
    ],
    "week": [
        "nedēļa",
        "ned"
    ],
    "day": [
        "diena",
        "d"
    ],
    "hour": [
        "stundas",
        "st",
        "h"
    ],
    "minute": [
        "minūtes",
        "min"
    ],
    "second": [
        "sekundes",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "pagājušajā gadā"
        ],
        "0 year ago": [
            "šajā gadā"
        ],
        "in 1 year": [
            "nākamajā gadā"
        ],
        "1 month ago": [
            "pagājušajā mēnesī"
        ],
        "0 month ago": [
            "šajā mēnesī"
        ],
        "in 1 month": [
            "nākamajā mēnesī"
        ],
        "1 week ago": [
            "pagājušajā nedēļā"
        ],
        "0 week ago": [
            "šajā nedēļā"
        ],
        "in 1 week": [
            "nākamajā nedēļā"
        ],
        "1 day ago": [
            "vakar"
        ],
        "0 day ago": [
            "šodien"
        ],
        "in 1 day": [
            "rīt"
        ],
        "0 hour ago": [
            "šajā stundā"
        ],
        "0 minute ago": [
            "šajā minūtē"
        ],
        "0 second ago": [
            "tagad"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "pēc (\\d+) gada",
            "pēc (\\d+) gadiem",
            "pēc (\\d+) g"
        ],
        "\\1 year ago": [
            "pirms (\\d+) gada",
            "pirms (\\d+) gadiem",
            "pirms (\\d+) g"
        ],
        "in \\1 month": [
            "pēc (\\d+) mēneša",
            "pēc (\\d+) mēnešiem",
            "pēc (\\d+) mēn"
        ],
        "\\1 month ago": [
            "pirms (\\d+) mēneša",
            "pirms (\\d+) mēnešiem",
            "pirms (\\d+) mēn"
        ],
        "in \\1 week": [
            "pēc (\\d+) nedēļas",
            "pēc (\\d+) nedēļām",
            "pēc (\\d+) ned"
        ],
        "\\1 week ago": [
            "pirms (\\d+) nedēļas",
            "pirms (\\d+) nedēļām",
            "pirms (\\d+) ned"
        ],
        "in \\1 day": [
            "pēc (\\d+) dienas",
            "pēc (\\d+) dienām",
            "pēc (\\d+) d"
        ],
        "\\1 day ago": [
            "pirms (\\d+) dienas",
            "pirms (\\d+) dienām",
            "pirms (\\d+) d"
        ],
        "in \\1 hour": [
            "pēc (\\d+) stundas",
            "pēc (\\d+) stundām",
            "pēc (\\d+) st",
            "pēc (\\d+) h"
        ],
        "\\1 hour ago": [
            "pirms (\\d+) stundas",
            "pirms (\\d+) stundām",
            "pirms (\\d+) st",
            "pirms (\\d+) h"
        ],
        "in \\1 minute": [
            "pēc (\\d+) minūtes",
            "pēc (\\d+) minūtēm",
            "pēc (\\d+) min"
        ],
        "\\1 minute ago": [
            "pirms (\\d+) minūtes",
            "pirms (\\d+) minūtēm",
            "pirms (\\d+) min"
        ],
        "in \\1 second": [
            "pēc (\\d+) sekundes",
            "pēc (\\d+) sekundēm",
            "pēc (\\d+) sek",
            "pēc (\\d+) s"
        ],
        "\\1 second ago": [
            "pirms (\\d+) sekundes",
            "pirms (\\d+) sekundēm",
            "pirms (\\d+) sek",
            "pirms (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "sk",
    "date_order": "DMY",
    "january": [
        "január",
        "jan",
        "januára"
    ],
    "february": [
        "február",
        "feb",
        "februára"
    ],
    "march": [
        "marec",
        "mar",
        "marca"
    ],
    "april": [
        "apríl",
        "apr",
        "apríla"
    ],
    "may": [
        "máj",
        "mája"
    ],
    "june": [
        "jún",
        "júna"
    ],
    "july": [
        "júl",
        "júla"
    ],
    "august": [
        "august",
        "aug",
        "augusta"
    ],
    "september": [
        "september",
        "sep",
        "septembra"
    ],
    "october": [
        "október",
        "okt",
        "októbra"
    ],
    "november": [
        "november",
        "nov",
        "novembra"
    ],
    "december": [
        "december",
        "dec",
        "decembra"
    ],
    "monday": [
        "pondelok",
        "po"
    ],
    "tuesday": [
        "utorok",
        "ut"
    ],
    "wednesday": [
        "streda",
        "st"
    ],
    "thursday": [
        "štvrtok",
        "št"
    ],
    "friday": [
        "piatok",
        "pi"
    ],
    "saturday": [
        "sobota",
        "so"
    ],
    "sunday": [
        "nedeľa",
        "ne"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "rok",
        "r"
    ],
    "month": [
        "mesiac",
        "mes"
    ],
    "week": [
        "týždeň",
        "týž"
    ],
    "day": [
        "deň",
        "d"
    ],
    "hour": [
        "hodina",
        "h"
    ],
    "minute": [
        "minúta",
        "min"
    ],
    "second": [
        "sekunda",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "minulý rok"
        ],
        "0 year ago": [
            "tento rok"
        ],
        "in 1 year": [
            "budúci rok"
        ],
        "1 month ago": [
            "minulý mesiac"
        ],
        "0 month ago": [
            "tento mesiac"
        ],
        "in 1 month": [
            "budúci mesiac"
        ],
        "1 week ago": [
            "minulý týždeň"
        ],
        "0 week ago": [
            "tento týždeň"
        ],
        "in 1 week": [
            "budúci týždeň"
        ],
        "1 day ago": [
            "včera"
        ],
        "0 day ago": [
            "dnes"
        ],
        "in 1 day": [
            "zajtra"
        ],
        "0 hour ago": [
            "v tejto hodine"
        ],
        "0 minute ago": [
            "v tejto minúte"
        ],
        "0 second ago": [
            "teraz"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "o (\\d+) rok",
            "o (\\d+) rokov",
            "o (\\d+) r"
        ],
        "\\1 year ago": [
            "pred (\\d+) rokom",
            "pred (\\d+) rokmi",
            "pred (\\d+) r"
        ],
        "in \\1 month": [
            "o (\\d+) mesiac",
            "o (\\d+) mesiacov",
            "o (\\d+) mes"
        ],
        "\\1 month ago": [
            "pred (\\d+) mesiacom",
            "pred (\\d+) mesiacmi",
            "pred (\\d+) mes"
        ],
        "in \\1 week": [
            "o (\\d+) týždeň",
            "o (\\d+) týždňov",
            "o (\\d+) týž"
        ],
        "\\1 week ago": [
            "pred (\\d+) týždňom",
            "pred (\\d+) týždňami",
            "pred (\\d+) týž"
        ],
        "in \\1 day": [
            "o (\\d+) deň",
            "o (\\d+) dní",
            "o (\\d+) d"
        ],
        "\\1 day ago": [
            "pred (\\d+) dňom",
            "pred (\\d+) dňami",
            "pred (\\d+) d"
        ],
        "in \\1 hour": [
            "o (\\d+) hodinu",
            "o (\\d+) hodín",
            "o (\\d+) h"
        ],
        "\\1 hour ago": [
            "pred (\\d+) hodinou",
            "pred (\\d+) hodinami",
            "pred (\\d+) h"
        ],
        "in \\1 minute": [
            "o (\\d+) minútu",
            "o (\\d+) minút",
            "o (\\d+) min"
        ],
        "\\1 minute ago": [
            "pred (\\d+) minútou",
            "pred (\\d+) minútami",
            "pred (\\d+) min"
        ],
        "in \\1 second": [
            "o (\\d+) sekundu",
            "o (\\d+) sekúnd",
            "o (\\d+) s"
        ],
        "\\1 second ago": [
            "pred (\\d+) sekundou",
            "pred (\\d+) sekundami",
            "pred (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "sn",
    "date_order": "YMD",
    "january": [
        "ndira",
        "ndi"
    ],
    "february": [
        "kukadzi",
        "kuk"
    ],
    "march": [
        "kurume",
        "kur"
    ],
    "april": [
        "kubvumbi",
        "kub"
    ],
    "may": [
        "chivabvu",
        "chv"
    ],
    "june": [
        "chikumi",
        "chk"
    ],
    "july": [
        "chikunguru",
        "chg"
    ],
    "august": [
        "nyamavhuvhu",
        "nya"
    ],
    "september": [
        "gunyana",
        "gun"
    ],
    "october": [
        "gumiguru",
        "gum"
    ],
    "november": [
        "mbudzi",
        "mbu"
    ],
    "december": [
        "zvita",
        "zvi"
    ],
    "monday": [
        "muvhuro",
        "muv"
    ],
    "tuesday": [
        "chipiri",
        "chp"
    ],
    "wednesday": [
        "chitatu",
        "cht"
    ],
    "thursday": [
        "china",
        "chn"
    ],
    "friday": [
        "chishanu",
        "chs"
    ],
    "saturday": [
        "mugovera",
        "mug"
    ],
    "sunday": [
        "svondo",
        "svo"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "gore"
    ],
    "month": [
        "mwedzi"
    ],
    "week": [
        "vhiki"
    ],
    "day": [
        "zuva"
    ],
    "hour": [
        "awa"
    ],
    "minute": [
        "mineti"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "nezuro"
        ],
        "0 day ago": [
            "nhasi"
        ],
        "in 1 day": [
            "mangwana"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "bez",
    "date_order": "DMY",
    "january": [
        "pa mwedzi gwa hutala",
        "hut"
    ],
    "february": [
        "pa mwedzi gwa wuvili",
        "vil"
    ],
    "march": [
        "pa mwedzi gwa wudatu",
        "dat"
    ],
    "april": [
        "pa mwedzi gwa wutai",
        "tai"
    ],
    "may": [
        "pa mwedzi gwa wuhanu",
        "han"
    ],
    "june": [
        "pa mwedzi gwa sita",
        "sit"
    ],
    "july": [
        "pa mwedzi gwa saba",
        "sab"
    ],
    "august": [
        "pa mwedzi gwa nane",
        "nan"
    ],
    "september": [
        "pa mwedzi gwa tisa",
        "tis"
    ],
    "october": [
        "pa mwedzi gwa kumi",
        "kum"
    ],
    "november": [
        "pa mwedzi gwa kumi na moja",
        "kmj"
    ],
    "december": [
        "pa mwedzi gwa kumi na mbili",
        "kmb"
    ],
    "monday": [
        "pa shahuviluha",
        "vil"
    ],
    "tuesday": [
        "pa hivili",
        "hiv"
    ],
    "wednesday": [
        "pa hidatu",
        "hid"
    ],
    "thursday": [
        "pa hitayi",
        "hit"
    ],
    "friday": [
        "pa hihanu",
        "hih"
    ],
    "saturday": [
        "pa shahulembela",
        "lem"
    ],
    "sunday": [
        "pa mulungu",
        "mul"
    ],
    "am": [
        "pamilau"
    ],
    "pm": [
        "pamunyi"
    ],
    "year": [
        "mwaha"
    ],
    "month": [
        "mwedzi"
    ],
    "week": [
        "mlungu gumamfu"
    ],
    "day": [
        "sihu"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "igolo"
        ],
        "0 day ago": [
            "neng'u ni"
        ],
        "in 1 day": [
            "hilawu"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "lu",
    "date_order": "DMY",
    "january": [
        "ciongo",
        "cio"
    ],
    "february": [
        "lùishi",
        "lui"
    ],
    "march": [
        "lusòlo",
        "lus"
    ],
    "april": [
        "mùuyà",
        "muu"
    ],
    "may": [
        "lumùngùlù",
        "lum"
    ],
    "june": [
        "lufuimi",
        "luf"
    ],
    "july": [
        "kabàlàshìpù",
        "kab"
    ],
    "august": [
        "lùshìkà",
        "lush"
    ],
    "september": [
        "lutongolo",
        "lut"
    ],
    "october": [
        "lungùdi",
        "lun"
    ],
    "november": [
        "kaswèkèsè",
        "kas"
    ],
    "december": [
        "ciswà",
        "cis"
    ],
    "monday": [
        "nkodya",
        "nko"
    ],
    "tuesday": [
        "ndàayà",
        "ndy"
    ],
    "wednesday": [
        "ndangù",
        "ndg"
    ],
    "thursday": [
        "njòwa",
        "njw"
    ],
    "friday": [
        "ngòvya",
        "ngv"
    ],
    "saturday": [
        "lubingu",
        "lub"
    ],
    "sunday": [
        "lumingu",
        "lum"
    ],
    "am": [
        "dinda"
    ],
    "pm": [
        "dilolo"
    ],
    "year": [
        "tshidimu"
    ],
    "month": [
        "ngondo"
    ],
    "week": [
        "lubingu"
    ],
    "day": [
        "dituku"
    ],
    "hour": [
        "diba"
    ],
    "minute": [
        "kasunsu"
    ],
    "second": [
        "kasunsukusu"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "makelela"
        ],
        "0 day ago": [
            "lelu"
        ],
        "in 1 day": [
            "malaba"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "kea",
    "date_order": "DMY",
    "january": [
        "janeru",
        "jan"
    ],
    "february": [
        "febreru",
        "feb"
    ],
    "march": [
        "marsu",
        "mar"
    ],
    "april": [
        "abril",
        "abr"
    ],
    "may": [
        "maiu",
        "mai"
    ],
    "june": [
        "junhu",
        "jun"
    ],
    "july": [
        "julhu",
        "jul"
    ],
    "august": [
        "agostu",
        "ago"
    ],
    "september": [
        "setenbru",
        "set"
    ],
    "october": [
        "otubru",
        "otu"
    ],
    "november": [
        "nuvenbru",
        "nuv"
    ],
    "december": [
        "dizenbru",
        "diz"
    ],
    "monday": [
        "sigunda-fera",
        "sig"
    ],
    "tuesday": [
        "tersa-fera",
        "ter"
    ],
    "wednesday": [
        "kuarta-fera",
        "kua"
    ],
    "thursday": [
        "kinta-fera",
        "kin"
    ],
    "friday": [
        "sesta-fera",
        "ses"
    ],
    "saturday": [
        "sábadu",
        "sab",
        "sabadu"
    ],
    "sunday": [
        "dumingu",
        "dum"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "anu"
    ],
    "month": [
        "mes"
    ],
    "week": [
        "simana",
        "sim"
    ],
    "day": [
        "dia"
    ],
    "hour": [
        "ora",
        "h"
    ],
    "minute": [
        "minutu",
        "min",
        "m"
    ],
    "second": [
        "sigundu",
        "sig",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "anu pasadu"
        ],
        "0 year ago": [
            "es anu li"
        ],
        "in 1 year": [
            "prósimu anu"
        ],
        "1 month ago": [
            "mes pasadu"
        ],
        "0 month ago": [
            "es mes li"
        ],
        "in 1 month": [
            "prósimu mes"
        ],
        "1 week ago": [
            "simana pasadu"
        ],
        "0 week ago": [
            "es simana li"
        ],
        "in 1 week": [
            "prósimu simana"
        ],
        "1 day ago": [
            "onti"
        ],
        "0 day ago": [
            "oji"
        ],
        "in 1 day": [
            "manha"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "di li (\\d+) anu"
        ],
        "\\1 year ago": [
            "a ten (\\d+) anu"
        ],
        "in \\1 month": [
            "di li (\\d+) mes"
        ],
        "\\1 month ago": [
            "a ten (\\d+) mes"
        ],
        "in \\1 week": [
            "di li (\\d+) simana",
            "di li (\\d+) sim"
        ],
        "\\1 week ago": [
            "a ten (\\d+) simana",
            "a ten (\\d+) sim"
        ],
        "in \\1 day": [
            "di li (\\d+) dia"
        ],
        "\\1 day ago": [
            "a ten (\\d+) dia"
        ],
        "in \\1 hour": [
            "di li (\\d+) ora"
        ],
        "\\1 hour ago": [
            "a ten (\\d+) ora"
        ],
        "in \\1 minute": [
            "di li (\\d+) minutu",
            "di li (\\d+) min",
            "di li (\\d+) m"
        ],
        "\\1 minute ago": [
            "a ten (\\d+) minutu",
            "a ten (\\d+) min",
            "a ten (\\d+) m"
        ],
        "in \\1 second": [
            "di li (\\d+) sigundu",
            "di li (\\d+) sig",
            "di li (\\d+) s"
        ],
        "\\1 second ago": [
            "a ten (\\d+) sigundu",
            "a ten (\\d+) sig",
            "a ten (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "mk",
    "date_order": "DMY",
    "january": [
        "јануари",
        "јан"
    ],
    "february": [
        "февруари",
        "фев"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "април",
        "апр"
    ],
    "may": [
        "мај"
    ],
    "june": [
        "јуни",
        "јун"
    ],
    "july": [
        "јули",
        "јул"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "септември",
        "септ"
    ],
    "october": [
        "октомври",
        "окт"
    ],
    "november": [
        "ноември",
        "ноем"
    ],
    "december": [
        "декември",
        "дек"
    ],
    "monday": [
        "понеделник",
        "пон"
    ],
    "tuesday": [
        "вторник",
        "вто",
        "вт"
    ],
    "wednesday": [
        "среда",
        "сре"
    ],
    "thursday": [
        "четврток",
        "чет"
    ],
    "friday": [
        "петок",
        "пет"
    ],
    "saturday": [
        "сабота",
        "саб"
    ],
    "sunday": [
        "недела",
        "нед"
    ],
    "am": [
        "претпладне",
        "претпл"
    ],
    "pm": [
        "попладне",
        "попл"
    ],
    "year": [
        "година",
        "год"
    ],
    "month": [
        "месец",
        "мес"
    ],
    "week": [
        "недела",
        "сед"
    ],
    "day": [
        "ден"
    ],
    "hour": [
        "час"
    ],
    "minute": [
        "минута",
        "мин"
    ],
    "second": [
        "секунда",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "минатата година"
        ],
        "0 year ago": [
            "оваа година"
        ],
        "in 1 year": [
            "следната година"
        ],
        "1 month ago": [
            "минатиот месец"
        ],
        "0 month ago": [
            "овој месец"
        ],
        "in 1 month": [
            "следниот месец"
        ],
        "1 week ago": [
            "минатата седмица"
        ],
        "0 week ago": [
            "оваа седмица"
        ],
        "in 1 week": [
            "следната седмица"
        ],
        "1 day ago": [
            "вчера"
        ],
        "0 day ago": [
            "денес"
        ],
        "in 1 day": [
            "утре"
        ],
        "0 hour ago": [
            "часов"
        ],
        "0 minute ago": [
            "оваа минута"
        ],
        "0 second ago": [
            "сега"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "за (\\d+) година",
            "за (\\d+) години"
        ],
        "\\1 year ago": [
            "пред (\\d+) година",
            "пред (\\d+) години"
        ],
        "in \\1 month": [
            "за (\\d+) месец",
            "за (\\d+) месеци"
        ],
        "\\1 month ago": [
            "пред (\\d+) месец",
            "пред (\\d+) месеци"
        ],
        "in \\1 week": [
            "за (\\d+) седмица",
            "за (\\d+) седмици"
        ],
        "\\1 week ago": [
            "пред (\\d+) седмица",
            "пред (\\d+) седмици"
        ],
        "in \\1 day": [
            "за (\\d+) ден",
            "за (\\d+) дена"
        ],
        "\\1 day ago": [
            "пред (\\d+) ден",
            "пред (\\d+) дена"
        ],
        "in \\1 hour": [
            "за (\\d+) час",
            "за (\\d+) часа"
        ],
        "\\1 hour ago": [
            "пред (\\d+) час",
            "пред (\\d+) часа"
        ],
        "in \\1 minute": [
            "за (\\d+) минута",
            "за (\\d+) минути"
        ],
        "\\1 minute ago": [
            "пред (\\d+) минута",
            "пред (\\d+) минути"
        ],
        "in \\1 second": [
            "за (\\d+) секунда",
            "за (\\d+) секунди"
        ],
        "\\1 second ago": [
            "пред (\\d+) секунда",
            "пред (\\d+) секунди"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "luo",
    "date_order": "DMY",
    "january": [
        "dwe mar achiel",
        "dac"
    ],
    "february": [
        "dwe mar ariyo",
        "dar"
    ],
    "march": [
        "dwe mar adek",
        "dad"
    ],
    "april": [
        "dwe mar ang'wen",
        "dan"
    ],
    "may": [
        "dwe mar abich",
        "dah"
    ],
    "june": [
        "dwe mar auchiel",
        "dau"
    ],
    "july": [
        "dwe mar abiriyo",
        "dao"
    ],
    "august": [
        "dwe mar aboro",
        "dab"
    ],
    "september": [
        "dwe mar ochiko",
        "doc"
    ],
    "october": [
        "dwe mar apar",
        "dap"
    ],
    "november": [
        "dwe mar gi achiel",
        "dgi"
    ],
    "december": [
        "dwe mar apar gi ariyo",
        "dag"
    ],
    "monday": [
        "wuok tich",
        "wut"
    ],
    "tuesday": [
        "tich ariyo",
        "tar"
    ],
    "wednesday": [
        "tich adek",
        "tad"
    ],
    "thursday": [
        "tich ang'wen",
        "tan"
    ],
    "friday": [
        "tich abich",
        "tab"
    ],
    "saturday": [
        "ngeso",
        "ngs"
    ],
    "sunday": [
        "jumapil",
        "jmp"
    ],
    "am": [
        "od"
    ],
    "pm": [
        "ot"
    ],
    "year": [
        "higa"
    ],
    "month": [
        "dwe"
    ],
    "week": [
        "juma"
    ],
    "day": [
        "chieng'"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "nyiriri mar saa"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "nyoro"
        ],
        "0 day ago": [
            "kawuono"
        ],
        "in 1 day": [
            "kiny"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import calendar
import collections
from datetime import datetime, timedelta
from warnings import warn

import six
import regex as re
from dateutil.relativedelta import relativedelta

from dateparser.date_parser import date_parser
from dateparser.freshness_date_parser import freshness_date_parser
from dateparser.languages.loader import LocaleDataLoader
from dateparser.conf import apply_settings
from dateparser.timezone_parser import pop_tz_offset_from_string
from dateparser.utils import apply_timezone_from_settings

try:
    # Python 3
    from collections.abc import Set
except ImportError:
    # Python 2.7
    from collections import Set

APOSTROPHE_LOOK_ALIKE_CHARS = [
    u'\N{RIGHT SINGLE QUOTATION MARK}',     # u'\u2019'
    u'\N{MODIFIER LETTER APOSTROPHE}',      # u'\u02bc'
    u'\N{MODIFIER LETTER TURNED COMMA}',    # u'\u02bb'
    u'\N{ARMENIAN APOSTROPHE}',             # u'\u055a'
    u'\N{LATIN SMALL LETTER SALTILLO}',     # u'\ua78c'
    u'\N{PRIME}',                           # u'\u2032'
    u'\N{REVERSED PRIME}',                  # u'\u2035'
    u'\N{MODIFIER LETTER PRIME}',           # u'\u02b9'
    u'\N{FULLWIDTH APOSTROPHE}',            # u'\uff07'
]

RE_NBSP = re.compile(u'\xa0', flags=re.UNICODE)
RE_SPACES = re.compile(r'\s+')
RE_TRIM_SPACES = re.compile(r'^\s+(\S.*?)\s+$')
RE_TRIM_COLONS = re.compile(r'(\S.*?):*$')

RE_SANITIZE_SKIP = re.compile(r'\t|\n|\r|\u00bb|,\s\u0432|\u200e|\xb7|\u200f|\u064e|\u064f', flags=re.M)
RE_SANITIZE_RUSSIAN = re.compile(r'([\W\d])\u0433\.', flags=re.I | re.U)
RE_SANITIZE_PERIOD = re.compile(r'(?<=\D+)\.', flags=re.U)
RE_SANITIZE_ON = re.compile(r'^.*?on:\s+(.*)')
RE_SANITIZE_APOSTROPHE = re.compile(u'|'.join(APOSTROPHE_LOOK_ALIKE_CHARS))

RE_SEARCH_TIMESTAMP = re.compile(r'^\d{10}(?![^\d.])')


def sanitize_spaces(date_string):
    date_string = RE_NBSP.sub(' ', date_string)
    date_string = RE_SPACES.sub(' ', date_string)
    date_string = RE_TRIM_SPACES.sub(r'\1', date_string)
    return date_string


def date_range(begin, end, **kwargs):
    dateutil_error_prone_args = ['year', 'month', 'week', 'day', 'hour',
                                 'minute', 'second']
    for arg in dateutil_error_prone_args:
        if arg in kwargs:
            raise ValueError("Invalid argument: %s" % arg)

    step = relativedelta(**kwargs) if kwargs else relativedelta(days=1)

    date = begin
    while date < end:
        yield date
        date += step

    # handles edge-case when iterating months and last interval is < 30 days
    if kwargs.get('months', 0) > 0 and (date.year, date.month) == (end.year, end.month):
        yield end


def get_intersecting_periods(low, high, period='day'):
    if period not in ['year', 'month', 'week', 'day', 'hour', 'minute', 'second', 'microsecond']:
        raise ValueError("Invalid period: {}".format(period))

    if high <= low:
        return

    step = relativedelta(**{period + 's': 1})

    current_period_start = low
    if isinstance(current_period_start, datetime):
        reset_arguments = {}
        for test_period in ['microsecond', 'second', 'minute', 'hour']:
            if test_period == period:
                break
            else:
                reset_arguments[test_period] = 0
        current_period_start = current_period_start.replace(**reset_arguments)

    if period == 'week':
        current_period_start \
            = current_period_start - timedelta(days=current_period_start.weekday())
    elif period == 'month':
        current_period_start = current_period_start.replace(day=1)
    elif period == 'year':
        current_period_start = current_period_start.replace(month=1, day=1)

    while current_period_start < high:
        yield current_period_start
        current_period_start += step


def sanitize_date(date_string):
    date_string = RE_SANITIZE_SKIP.sub(' ', date_string)
    date_string = RE_SANITIZE_RUSSIAN.sub(r'\1 ', date_string)  # remove u'г.' (Russian for year) but not in words
    date_string = sanitize_spaces(date_string)
    date_string = RE_SANITIZE_PERIOD.sub('', date_string)
    date_string = RE_SANITIZE_ON.sub(r'\1', date_string)
    date_string = RE_TRIM_COLONS.sub(r'\1', date_string)

    date_string = RE_SANITIZE_APOSTROPHE.sub(u"'", date_string)

    return date_string


def get_date_from_timestamp(date_string, settings):
    if RE_SEARCH_TIMESTAMP.search(date_string):
        date_obj = datetime.fromtimestamp(int(date_string[:10]))
        date_obj = apply_timezone_from_settings(date_obj, settings)
        return date_obj


def get_last_day_of_month(year, month):
    return calendar.monthrange(year, month)[1]


def parse_with_formats(date_string, date_formats, settings):
    """ Parse with formats and return a dictionary with 'period' and 'obj_date'.

    :returns: :class:`datetime.datetime`, dict or None

    """
    if isinstance(date_formats, six.string_types):
        warn(_DateLocaleParser.DATE_FORMATS_ERROR_MESSAGE, FutureWarning)
        date_formats = [date_formats]
    period = 'day'
    for date_format in date_formats:
        try:
            date_obj = datetime.strptime(date_string, date_format)
        except ValueError:
            continue
        else:
            # If format does not include the day, use last day of the month
            # instead of first, because the first is usually out of range.
            if '%d' not in date_format:
                period = 'month'
                date_obj = date_obj.replace(
                    day=get_last_day_of_month(date_obj.year, date_obj.month))

            if not ('%y' in date_format or '%Y' in date_format):
                today = datetime.today()
                date_obj = date_obj.replace(year=today.year)

            date_obj = apply_timezone_from_settings(date_obj, settings)

            return {'date_obj': date_obj, 'period': period}
    else:
        return {'date_obj': None, 'period': period}


class _DateLocaleParser(object):
    DATE_FORMATS_ERROR_MESSAGE = "Date formats should be list, tuple or set of strings"

    def __init__(self, locale, date_string, date_formats, settings=None):
        self._settings = settings
        if isinstance(date_formats, six.string_types):
            warn(self.DATE_FORMATS_ERROR_MESSAGE, FutureWarning)
            date_formats = [date_formats]
        elif not (date_formats is None or isinstance(date_formats, (list, tuple, Set))):
            raise TypeError(self.DATE_FORMATS_ERROR_MESSAGE)

        self.locale = locale
        self.date_string = date_string
        self.date_formats = date_formats
        self._translated_date = None
        self._translated_date_with_formatting = None

    @classmethod
    def parse(cls, locale, date_string, date_formats=None, settings=None):
        instance = cls(locale, date_string, date_formats, settings)
        return instance._parse()

    def _parse(self):
        for parser in (
            self._try_timestamp,
            self._try_freshness_parser,
            self._try_given_formats,
            self._try_parser,
            self._try_hardcoded_formats,
        ):
            date_obj = parser()
            if self._is_valid_date_obj(date_obj):
                return date_obj
        else:
            return None

    def _try_timestamp(self):
        return {
            'date_obj': get_date_from_timestamp(self.date_string, self._settings),
            'period': 'day',
        }

    def _try_freshness_parser(self):
        return freshness_date_parser.get_date_data(self._get_translated_date(), self._settings)

    def _try_parser(self):
        _order = self._settings.DATE_ORDER
        _default_date_order = self._settings._pyfile_data.get('DATE_ORDER')
        try:
            if self._settings.PREFER_LOCALE_DATE_ORDER:
                if _order == _default_date_order:
                    self._settings.DATE_ORDER = self.locale.info.get('date_order', _order)
            date_obj, period = date_parser.parse(
                self._get_translated_date(), settings=self._settings)
            self._settings.DATE_ORDER = _order
            return {
                'date_obj': date_obj,
                'period': period,
            }
        except ValueError:
            self._settings.DATE_ORDER = _order
            return None

    def _try_given_formats(self):
        if not self.date_formats:
            return

        return parse_with_formats(
            self._get_translated_date_with_formatting(),
            self.date_formats, settings=self._settings
        )

    def _try_hardcoded_formats(self):
        hardcoded_date_formats = [
            '%B %d, %Y, %I:%M:%S %p',
            '%b %d, %Y at %I:%M %p',
            '%d %B %Y %H:%M:%S',
            '%A, %B %d, %Y',
            '%Y-%m-%dT%H:%M:%S.%fZ'
        ]
        try:
            return parse_with_formats(
                self._get_translated_date_with_formatting(),
                hardcoded_date_formats,
                settings=self._settings
            )
        except TypeError:
            return None

    def _get_translated_date(self):
        if self._translated_date is None:
            self._translated_date = self.locale.translate(
                self.date_string, keep_formatting=False, settings=self._settings)
        return self._translated_date

    def _get_translated_date_with_formatting(self):
        if self._translated_date_with_formatting is None:
            self._translated_date_with_formatting = self.locale.translate(
                self.date_string, keep_formatting=True, settings=self._settings)
        return self._translated_date_with_formatting

    def _is_valid_date_obj(self, date_obj):
        if not isinstance(date_obj, dict):
            return False
        if len(date_obj) != 2:
            return False
        if 'date_obj' not in date_obj or 'period' not in date_obj:
            return False
        if not date_obj['date_obj']:
            return False
        if date_obj['period'] not in ('time', 'day', 'week', 'month', 'year'):
            return False

        return True


class DateDataParser(object):
    """
    Class which handles language detection, translation and subsequent generic parsing of
    string representing date and/or time.

    :param languages:
        A list of language codes, e.g. ['en', 'es', 'zh-Hant'].
        If locales are not given, languages and region are
        used to construct locales for translation.
    :type languages: list

    :param locales:
        A list of locale codes, e.g. ['fr-PF', 'qu-EC', 'af-NA'].
        The parser uses locales to translate date string.
    :type locales: list

    :param region:
        A region code, e.g. 'IN', '001', 'NE'.
        If locales are not given, languages and region are
        used to construct locales for translation.
    :type region: str|unicode

    :param try_previous_locales:
        If True, locales previously used to translate date are tried first.
    :type allow_redetect_language: bool

    :param use_given_order:
        If True, locales are tried for translation of date string
        in the order in which they are given.
    :type allow_redetect_language: bool

    :param settings:
        Configure customized behavior using settings defined in :mod:`dateparser.conf.Settings`.
    :type settings: dict

    :return: A parser instance

    :raises:
        ValueError - Unknown Language, TypeError - Languages argument must be a list
    """

    locale_loader = None

    @apply_settings
    def __init__(self, languages=None, locales=None, region=None, try_previous_locales=True,
                 use_given_order=False, settings=None):

        if not isinstance(languages, (list, tuple, Set)) and languages is not None:
            raise TypeError("languages argument must be a list (%r given)" % type(languages))

        if not isinstance(locales, (list, tuple, Set)) and locales is not None:
            raise TypeError("locales argument must be a list (%r given)" % type(locales))

        if not isinstance(region, six.string_types) and region is not None:
            raise TypeError("region argument must be str or unicode (%r given)" % type(region))

        if not isinstance(try_previous_locales, bool):
            raise TypeError("try_previous_locales argument must be a boolean (%r given)"
                            % type(try_previous_locales))

        if not isinstance(use_given_order, bool):
            raise TypeError("use_given_order argument must be a boolean (%r given)"
                            % type(use_given_order))

        if not locales and use_given_order:
            raise ValueError("locales must be given if use_given_order is True")

        self._settings = settings
        self.try_previous_locales = try_previous_locales
        self.use_given_order = use_given_order
        self.languages = languages
        self.locales = locales
        self.region = region
        self.previous_locales = []

    def get_date_data(self, date_string, date_formats=None):
        """
        Parse string representing date and/or time in recognizable localized formats.
        Supports parsing multiple languages and timezones.

        :param date_string:
            A string representing date and/or time in a recognizably valid format.
        :type date_string: str|unicode
        :param date_formats:
            A list of format strings using directives as given
            `here <https://docs.python.org/2/library/datetime.html#strftime-and-strptime-behavior>`_.
            The parser applies formats one by one, taking into account the detected languages.
        :type date_formats: list

        :return: a dict mapping keys to :mod:`datetime.datetime` object and *period*. For example:
            {'date_obj': datetime.datetime(2015, 6, 1, 0, 0), 'period': u'day'}

        :raises: ValueError - Unknown Language

        .. note:: *Period* values can be a 'day' (default), 'week', 'month', 'year'.

        *Period* represents the granularity of date parsed from the given string.

        In the example below, since no day information is present, the day is assumed to be current
        day ``16`` from *current date* (which is June 16, 2015, at the moment of writing this).
        Hence, the level of precision is ``month``:

            >>> DateDataParser().get_date_data(u'March 2015')
            {'date_obj': datetime.datetime(2015, 3, 16, 0, 0), 'period': u'month'}

        Similarly, for date strings with no day and month information present, level of precision
        is ``year`` and day ``16`` and month ``6`` are from *current_date*.

            >>> DateDataParser().get_date_data(u'2014')
            {'date_obj': datetime.datetime(2014, 6, 16, 0, 0), 'period': u'year'}

        Dates with time zone indications or UTC offsets are returned in UTC time unless
        specified using `Settings`_.

            >>> DateDataParser().get_date_data(u'23 March 2000, 1:21 PM CET')
            {'date_obj': datetime.datetime(2000, 3, 23, 14, 21), 'period': 'day'}

        """
        if not(isinstance(date_string, six.text_type) or isinstance(date_string, six.string_types)):
            raise TypeError('Input type must be str or unicode')

        if isinstance(date_string, bytes):
            date_string = date_string.decode('utf-8')

        res = parse_with_formats(date_string, date_formats or [], self._settings)
        if res['date_obj']:
            return res

        date_string = sanitize_date(date_string)

        for locale in self._get_applicable_locales(date_string):
            parsed_date = _DateLocaleParser.parse(
                locale, date_string, date_formats, settings=self._settings)
            if parsed_date:
                parsed_date['locale'] = locale.shortname
                if self.try_previous_locales:
                    self.previous_locales.insert(0, locale)
                return parsed_date
        else:
            return {'date_obj': None, 'period': 'day', 'locale': None}

    def get_date_tuple(self, *args, **kwargs):
        date_tuple = collections.namedtuple('DateData', 'date_obj period locale')
        date_data = self.get_date_data(*args, **kwargs)
        return date_tuple(**date_data)

    def _get_applicable_locales(self, date_string):
        pop_tz_cache = []

        def date_strings():
            """ A generator instead of a static list to avoid calling
            pop_tz_offset_from_string if the first locale matches on unmodified
            date_string.
            """
            yield date_string
            if not pop_tz_cache:
                stripped_date_string, _ = pop_tz_offset_from_string(
                    date_string, as_offset=False)
                if stripped_date_string == date_string:
                    stripped_date_string = None
                pop_tz_cache[:] = [stripped_date_string]
            stripped_date_string, = pop_tz_cache
            if stripped_date_string is not None:
                yield stripped_date_string

        if self.try_previous_locales:
            for locale in self.previous_locales:
                for s in date_strings():
                    if self._is_applicable_locale(locale, s):
                        yield locale

        for locale in self._get_locale_loader().get_locales(
                languages=self.languages, locales=self.locales, region=self.region,
                use_given_order=self.use_given_order):
            for s in date_strings():
                if self._is_applicable_locale(locale, s):
                    yield locale

    def _is_applicable_locale(self, locale, date_string):
        return locale.is_applicable(
            date_string,
            strip_timezone=False,  # it is stripped outside
            settings=self._settings)

    @classmethod
    def _get_locale_loader(cls):
        if not cls.locale_loader:
            cls.locale_loader = LocaleDataLoader()
        return cls.locale_loader



# -*- coding: utf-8 -*-
import hashlib
from functools import wraps
import six

from .utils import registry

@registry
class Settings(object):
    """Control and configure default parsing behavior of dateparser.
    Currently, supported settings are:

    * `PREFER_DATES_FROM`: defaults to `current_period`. Options are `future` or `past`.
    * `SUPPORT_BEFORE_COMMON_ERA`: defaults to `False`.
    * `PREFER_DAY_OF_MONTH`: defaults to `current`. Could be `first` and `last` day of month.
    * `SKIP_TOKENS`: defaults to `['t']`. Can be any string.
    * `TIMEZONE`: defaults to `UTC`. Can be timezone abbreviation or any of `tz database name as given here <https://en.wikipedia.org/wiki/List_of_tz_database_time_zones>`_.
    * `RETURN_AS_TIMEZONE_AWARE`: return tz aware datetime objects in case timezone is detected in the date string.
    * `RELATIVE_BASE`: count relative date from this base date. Should be datetime object.
    * `RETURN_TIME_AS_PERIOD`: returns period as `time` in case time component is detected in the date string.
    Default: False.
    """

    _default = True
    _pyfile_data = None

    def __init__(self, settings=None):
        if settings:
            self._updateall(settings.items())
        else:
            self._updateall(self._get_settings_from_pyfile().items())

    @classmethod
    def get_key(cls, settings=None):
        if not settings:
            return 'default'

        keys = sorted(['%s-%s' % (key, str(settings[key])) for key in settings])
        return hashlib.md5(''.join(keys).encode('utf-8')).hexdigest()

    @classmethod
    def _get_settings_from_pyfile(cls):
        if not cls._pyfile_data:
            from dateparser_data import settings
            cls._pyfile_data = settings.settings
        return cls._pyfile_data

    def _updateall(self, iterable):
        for key, value in iterable:
            setattr(self, key, value)

    def replace(self, **kwds):
        for k, v in six.iteritems(kwds):
            if v is None:
                raise TypeError('Invalid {{"{}": {}}}'.format(k, v))

        for x in six.iterkeys(self._get_settings_from_pyfile()):
            kwds.setdefault(x, getattr(self, x))

        kwds['_default'] = False

        return self.__class__(settings=kwds)


settings = Settings()


def apply_settings(f):
    @wraps(f)
    def wrapper(*args, **kwargs):
        kwargs['settings'] = kwargs.get('settings', settings)

        if kwargs['settings'] is None:
            kwargs['settings'] = settings

        if isinstance(kwargs['settings'], dict):
            kwargs['settings'] = settings.replace(**kwargs['settings'])

        if not isinstance(kwargs['settings'], Settings):
            raise TypeError(
                "settings can only be either dict or instance of Settings class")

        return f(*args, **kwargs)
    return wrapper



# -*- coding: utf-8 -*-
info = {
    "name": "az-Cyrl",
    "date_order": "DMY",
    "january": [
        "јанвар",
        "јан"
    ],
    "february": [
        "феврал",
        "фев"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "апрел",
        "апр"
    ],
    "may": [
        "май"
    ],
    "june": [
        "ијун",
        "ијн"
    ],
    "july": [
        "ијул",
        "ијл"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "сентјабр",
        "сен"
    ],
    "october": [
        "октјабр",
        "окт"
    ],
    "november": [
        "нојабр",
        "ној"
    ],
    "december": [
        "декабр",
        "дек"
    ],
    "monday": [
        "базар ертәси",
        "бе"
    ],
    "tuesday": [
        "чәршәнбә ахшамы",
        "ча"
    ],
    "wednesday": [
        "чәршәнбә",
        "ч"
    ],
    "thursday": [
        "ҹүмә ахшамы",
        "ҹа"
    ],
    "friday": [
        "ҹүмә",
        "ҹ"
    ],
    "saturday": [
        "шәнбә",
        "ш"
    ],
    "sunday": [
        "базар",
        "б"
    ],
    "am": [
        "ам"
    ],
    "pm": [
        "пм"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "0 day ago": [
            "today"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}


# -*- coding: utf-8 -*-
info = {
    "name": "da",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "marts",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "december",
        "dec"
    ],
    "monday": [
        "mandag",
        "man"
    ],
    "tuesday": [
        "tirsdag",
        "tir"
    ],
    "wednesday": [
        "onsdag",
        "ons"
    ],
    "thursday": [
        "torsdag",
        "tor"
    ],
    "friday": [
        "fredag",
        "fre"
    ],
    "saturday": [
        "lørdag",
        "lør"
    ],
    "sunday": [
        "søndag",
        "søn"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "år"
    ],
    "month": [
        "måned",
        "md",
        "måneder"
    ],
    "week": [
        "uge",
        "uger"
    ],
    "day": [
        "dag",
        "dage"
    ],
    "hour": [
        "time",
        "t",
        "timer"
    ],
    "minute": [
        "minut",
        "min",
        "minutter"
    ],
    "second": [
        "sekund",
        "sek",
        "s",
        "sekunder"
    ],
    "relative-type": {
        "1 year ago": [
            "sidste år"
        ],
        "0 year ago": [
            "i år"
        ],
        "in 1 year": [
            "næste år"
        ],
        "1 month ago": [
            "sidste måned",
            "sidste md"
        ],
        "0 month ago": [
            "denne måned",
            "denne md"
        ],
        "in 1 month": [
            "næste måned",
            "næste md"
        ],
        "1 week ago": [
            "sidste uge"
        ],
        "0 week ago": [
            "denne uge"
        ],
        "in 1 week": [
            "næste uge"
        ],
        "1 day ago": [
            "i går"
        ],
        "0 day ago": [
            "i dag"
        ],
        "in 1 day": [
            "i morgen"
        ],
        "0 hour ago": [
            "i den kommende time"
        ],
        "0 minute ago": [
            "i det kommende minut"
        ],
        "0 second ago": [
            "nu"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "om (\\d+) år"
        ],
        "\\1 year ago": [
            "for (\\d+) år siden"
        ],
        "in \\1 month": [
            "om (\\d+) måned",
            "om (\\d+) måneder",
            "om (\\d+) md",
            "om (\\d+) mdr"
        ],
        "\\1 month ago": [
            "for (\\d+) måned siden",
            "for (\\d+) måneder siden",
            "for (\\d+) md siden",
            "for (\\d+) mdr siden"
        ],
        "in \\1 week": [
            "om (\\d+) uge",
            "om (\\d+) uger"
        ],
        "\\1 week ago": [
            "for (\\d+) uge siden",
            "for (\\d+) uger siden"
        ],
        "in \\1 day": [
            "om (\\d+) dag",
            "om (\\d+) dage"
        ],
        "\\1 day ago": [
            "for (\\d+) dag siden",
            "for (\\d+) dage siden"
        ],
        "in \\1 hour": [
            "om (\\d+) time",
            "om (\\d+) timer"
        ],
        "\\1 hour ago": [
            "for (\\d+) time siden",
            "for (\\d+) timer siden",
            "for (\\d+)\\s*h",
            "for (\\d+) timer"
        ],
        "in \\1 minute": [
            "om (\\d+) minut",
            "om (\\d+) minutter",
            "om (\\d+) min"
        ],
        "\\1 minute ago": [
            "for (\\d+) minut siden",
            "for (\\d+) minutter siden",
            "for (\\d+) min siden",
            "for (\\d+)\\s*m",
            "for (\\d+) minutter"
        ],
        "in \\1 second": [
            "om (\\d+) sekund",
            "om (\\d+) sekunder",
            "om (\\d+) sek"
        ],
        "\\1 second ago": [
            "for (\\d+) sekund siden",
            "for (\\d+) sekunder siden",
            "for (\\d+) sek siden",
            "for (\\d+)\\s*s",
            "for (\\d+) sekunder"
        ]
    },
    "locale_specific": {
        "da-GL": {
            "name": "da-GL"
        }
    },
    "skip": [
        "kl",
        "kl.",
        "cirka",
        "d.",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "siden"
    ],
    "in": [
        "i"
    ],
    "simplifications": [
        {
            "en": "1"
        },
        {
            "et": "1"
        },
        {
            "(\\d+)\\s*hr(s?)": "\\1 time\\2"
        },
        {
            "(\\d+)\\s*min(s?)": "\\1 minut\\2"
        },
        {
            "(\\d+)\\s*sec(s?)": "\\1 sekund\\2"
        },
        {
            "middag": "12:00"
        },
        {
            "midnat": "00:00"
        },
        {
            "(\\d+)h(\\d+)m?": "\\1:\\2"
        },
        {
            "mindre end 1 minut siden": "45 seconds"
        }
    ]
}